@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: attoparsec
-version: 0.13.0.1
-id: attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
-key: attop_C6pUTDzrecbIO4LDYHwJUG
+version: 0.13.0.2
+id: attoparsec-0.13.0.2-669cbb29a91e49834657a781d3adc2de
+key: attop_41FU8li3hiTHrQHazQNzh3
 license: BSD3
 maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
 stability: experimental
@@ -30,10 +30,10 @@ hidden-modules: Data.Attoparsec.ByteString.Buffer
                 Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Text.Buffer
                 Data.Attoparsec.Text.FastSet Data.Attoparsec.Text.Internal
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/attoparsec-0.13.0.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/attoparsec-0.13.0.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/attoparsec-0.13.0.1
-hs-libraries: HSattoparsec-0.13.0.1-C6pUTDzrecbIO4LDYHwJUG
+import-dirs: /usr/lib/ghc-7.10.3/site-local/attoparsec-0.13.0.2
+library-dirs: /usr/lib/ghc-7.10.3/site-local/attoparsec-0.13.0.2
+data-dir: /usr/share/arm-linux-ghc-7.10.3/attoparsec-0.13.0.2
+hs-libraries: HSattoparsec-0.13.0.2-41FU8li3hiTHrQHazQNzh3
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
